@@ -4,6 +4,7 @@
 
 // 项目自身文件
 #include "PanguxGenerator.h"
+#include "DDLog.h"
 
 // 其它头文件
 #include <QRegularExpression>
@@ -11,13 +12,16 @@
 #include "../DeviceManager/DeviceBluetooth.h"
 #include "DeviceManager/DeviceManager.h"
 
+using namespace DDLog;
+
 PanguXGenerator::PanguXGenerator()
 {
-
+    qCDebug(appLog) << "PanguXGenerator constructor";
 }
 
 void PanguXGenerator::getAudioInfoFromCatAudio()
 {
+    qCDebug(appLog) << "PanguXGenerator::getAudioInfoFromCatAudio start";
     QMap<QString, QString> tempMap;
     tempMap["Name"] = "OnBoard Audio";
     tempMap["Vendor"]= "HUAWEI";
@@ -29,10 +33,12 @@ void PanguXGenerator::getAudioInfoFromCatAudio()
     DeviceManager::instance()->addAudioDevice(device);
 
     getAudioInfoFromHwinfo();
+    qCDebug(appLog) << "PanguXGenerator::getAudioInfoFromCatAudio end";
 }
 
 void PanguXGenerator::generatorBluetoothDevice()
 {
+    qCDebug(appLog) << "PanguXGenerator::generatorBluetoothDevice start";
     DeviceBluetooth *device0 = new DeviceBluetooth();
     QMap<QString, QString> tempMap;
     tempMap["Vendor"] = "HISILICON";
@@ -65,6 +71,7 @@ void PanguXGenerator::generatorBluetoothDevice()
 }
 void PanguXGenerator::generatorCpuDevice()
 {
+    qCDebug(appLog) << "PanguXGenerator::generatorCpuDevice start";
     HWGenerator::generatorCpuDevice();
 
     QFile file("/proc/cpuinfo");
@@ -99,4 +106,5 @@ void PanguXGenerator::generatorCpuDevice()
         DeviceBaseInfo *device = lst[i];
         DeviceManager::instance()->tomlDeviceSet(DT_Cpu, device,mapInfo);
     }
+    qCDebug(appLog) << "PanguXGenerator::generatorCpuDevice end";
 }
